SWDEV-341956 - update HIP Dtest with correct coordinates (#2755)
Change-Id: Iaccc4251a984e690d680ce884c6bfcc1093703af
[ROCm/hip commit: 2667f3e225]
This commit is contained in:
committato da
GitHub
parent
47a1198e18
commit
da2888b9c4
@@ -60,7 +60,7 @@ template<typename T>
|
||||
__global__ void normalizedValTextureTest(unsigned int numElements, float* pDst)
|
||||
{
|
||||
#if !defined(__HIP_NO_IMAGE_SUPPORT) || !__HIP_NO_IMAGE_SUPPORT
|
||||
unsigned int elementID = hipThreadIdx_x;
|
||||
unsigned int elementID = threadIdx.x;
|
||||
if(elementID >= numElements)
|
||||
return;
|
||||
float coord =(float) elementID/numElements;
|
||||
|
||||
Fai riferimento in un nuovo problema
Block a user